# 1.0.0 (2022-04-18)


### Features

* initial release ([#1](https://github.com/seba-ban/env-var/issues/1)) ([251463a](https://github.com/seba-ban/env-var/commit/251463ad323eb90f4e629d5527dfbfa4dfc8ea33))
